diff mbox series

makedevs: Fix issue when rootdir of / is given

Message ID 20240806115558.1884414-1-jaeyoon.jung@lge.com
State New
Headers show
Series makedevs: Fix issue when rootdir of / is given | expand

Commit Message

jaeyoon.jung@lge.com Aug. 6, 2024, 11:55 a.m. UTC
From: Jaeyoon Jung <jaeyoon.jung@lge.com>

Treating rootdir "/" as "" leads an error in parse_devtable(). Preserve
it as it is given and use a separate variable for path name prepending.
Another minor fix is to add a return statement at the end of
convert2guid() to avoid an error with -Werror=return-type.

Signed-off-by: Jaeyoon Jung <jaeyoon.jung@lge.com>
---
 .../makedevs/makedevs/makedevs.c              | 21 +++++++++++--------
 1 file changed, 12 insertions(+), 9 deletions(-)
diff mbox series

Patch

diff --git a/meta/recipes-devtools/makedevs/makedevs/makedevs.c b/meta/recipes-devtools/makedevs/makedevs/makedevs.c
index df2e3cfad5..5c29bcf2f2 100644
--- a/meta/recipes-devtools/makedevs/makedevs/makedevs.c
+++ b/meta/recipes-devtools/makedevs/makedevs/makedevs.c
@@ -36,6 +36,7 @@  static const char *const app_name = "makedevs";
 static const char *const memory_exhausted = "memory exhausted";
 static char default_rootdir[]=".";
 static char *rootdir = default_rootdir;
+static char *rootdir_prepend = default_rootdir;
 static int trace = 0;
 
 struct name_id {
@@ -217,6 +218,9 @@  static unsigned long convert2guid(char *id_buf, struct name_id *search_list)
 		}
 		error_msg_and_die("No entry for %s in search list", id_buf);
 	}
+
+    // Unreachable, but avoid an error with -Werror=return-type
+    return 0;
 }
 
 static void free_list(struct name_id *list)
@@ -379,8 +383,8 @@  static int interpret_table_entry(char *line)
 		error_msg_and_die("Device table entries require absolute paths");
 	}
 	name = xstrdup(path + 1);
-	/* prefix path with rootdir */
-	sprintf(path, "%s/%s", rootdir, name);
+	/* prefix path with rootdir_prepend */
+	sprintf(path, "%s/%s", rootdir_prepend, name);
 
 	/* XXX Why is name passed into all of the add_new_*() routines? */
 	switch (type) {
@@ -406,11 +410,11 @@  static int interpret_table_entry(char *line)
 
 			for (i = start; i < start + count; i++) {
 				sprintf(buf, "%s%d", name, i);
-				sprintf(path, "%s/%s%d", rootdir, name, i);
+				sprintf(path, "%s/%s%d", rootdir_prepend, name, i);
 				/* FIXME:  MKDEV uses illicit insider knowledge of kernel
 				 * major/minor representation...  */
 				rdev = MKDEV(major, minor + (i - start) * increment);
-				sprintf(path, "%s/%s\0", rootdir, buf);
+				sprintf(path, "%s/%s\0", rootdir_prepend, buf);
 				add_new_device(buf, path, uid, gid, mode, rdev);
 			}
 		} else {
@@ -541,12 +545,11 @@  int main(int argc, char **argv)
 			} else {
 				closedir(dir);
 			}
-			/* If "/" is specified, use "" because rootdir is always prepended to a
-			 * string that starts with "/" */
-			if (0 == strcmp(optarg, "/"))
-				rootdir = xstrdup("");
+			rootdir = xstrdup(optarg);
+			if (0 == strcmp(rootdir, "/"))
+				rootdir_prepend = xstrdup("");
 			else
-				rootdir = xstrdup(optarg);
+				rootdir_prepend = xstrdup(rootdir);
 			break;
 
 		case 't':